Documentation
¶
Index ¶
- type BackendConfigLister
- type BackendConfigListerExpansion
- type BackendConfigNamespaceLister
- type BackendConfigNamespaceListerExpansion
- type TemplateConfigLister
- type TemplateConfigListerExpansion
- type TemplateConfigNamespaceLister
- type TemplateConfigNamespaceListerExpansion
- type VarnishConfigLister
- type VarnishConfigListerExpansion
- type VarnishConfigNamespaceLister
- type VarnishConfigNamespaceListerExpansion
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BackendConfigLister ¶
type BackendConfigLister interface {
// List lists all BackendConfigs in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.BackendConfig, err error)
// BackendConfigs returns an object that can list and get BackendConfigs.
BackendConfigs(namespace string) BackendConfigNamespaceLister
BackendConfigListerExpansion
}
BackendConfigLister helps list BackendConfigs. All objects returned here must be treated as read-only.
func NewBackendConfigLister ¶
func NewBackendConfigLister(indexer cache.Indexer) BackendConfigLister
NewBackendConfigLister returns a new BackendConfigLister.
type BackendConfigListerExpansion ¶
type BackendConfigListerExpansion interface{}
BackendConfigListerExpansion allows custom methods to be added to BackendConfigLister.
type BackendConfigNamespaceLister ¶
type BackendConfigNamespaceLister interface {
// List lists all BackendConfigs in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.BackendConfig, err error)
// Get retrieves the BackendConfig from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.BackendConfig, error)
BackendConfigNamespaceListerExpansion
}
BackendConfigNamespaceLister helps list and get BackendConfigs. All objects returned here must be treated as read-only.
type BackendConfigNamespaceListerExpansion ¶
type BackendConfigNamespaceListerExpansion interface{}
BackendConfigNamespaceListerExpansion allows custom methods to be added to BackendConfigNamespaceLister.
type TemplateConfigLister ¶
type TemplateConfigLister interface {
// List lists all TemplateConfigs in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.TemplateConfig, err error)
// TemplateConfigs returns an object that can list and get TemplateConfigs.
TemplateConfigs(namespace string) TemplateConfigNamespaceLister
TemplateConfigListerExpansion
}
TemplateConfigLister helps list TemplateConfigs. All objects returned here must be treated as read-only.
func NewTemplateConfigLister ¶
func NewTemplateConfigLister(indexer cache.Indexer) TemplateConfigLister
NewTemplateConfigLister returns a new TemplateConfigLister.
type TemplateConfigListerExpansion ¶
type TemplateConfigListerExpansion interface{}
TemplateConfigListerExpansion allows custom methods to be added to TemplateConfigLister.
type TemplateConfigNamespaceLister ¶
type TemplateConfigNamespaceLister interface {
// List lists all TemplateConfigs in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.TemplateConfig, err error)
// Get retrieves the TemplateConfig from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.TemplateConfig, error)
TemplateConfigNamespaceListerExpansion
}
TemplateConfigNamespaceLister helps list and get TemplateConfigs. All objects returned here must be treated as read-only.
type TemplateConfigNamespaceListerExpansion ¶
type TemplateConfigNamespaceListerExpansion interface{}
TemplateConfigNamespaceListerExpansion allows custom methods to be added to TemplateConfigNamespaceLister.
type VarnishConfigLister ¶
type VarnishConfigLister interface {
// List lists all VarnishConfigs in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.VarnishConfig, err error)
// VarnishConfigs returns an object that can list and get VarnishConfigs.
VarnishConfigs(namespace string) VarnishConfigNamespaceLister
VarnishConfigListerExpansion
}
VarnishConfigLister helps list VarnishConfigs. All objects returned here must be treated as read-only.
func NewVarnishConfigLister ¶
func NewVarnishConfigLister(indexer cache.Indexer) VarnishConfigLister
NewVarnishConfigLister returns a new VarnishConfigLister.
type VarnishConfigListerExpansion ¶
type VarnishConfigListerExpansion interface{}
VarnishConfigListerExpansion allows custom methods to be added to VarnishConfigLister.
type VarnishConfigNamespaceLister ¶
type VarnishConfigNamespaceLister interface {
// List lists all VarnishConfigs in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.VarnishConfig, err error)
// Get retrieves the VarnishConfig from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.VarnishConfig, error)
VarnishConfigNamespaceListerExpansion
}
VarnishConfigNamespaceLister helps list and get VarnishConfigs. All objects returned here must be treated as read-only.
type VarnishConfigNamespaceListerExpansion ¶
type VarnishConfigNamespaceListerExpansion interface{}
VarnishConfigNamespaceListerExpansion allows custom methods to be added to VarnishConfigNamespaceLister.