Documentation
¶
Overview ¶
Package interfaces defines interfaces that allow pkg/controller and pkg/varnish to access code from one another without introducing import cycles.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type SvcEventGenerator ¶
type SvcEventGenerator interface {
SvcInfoEvent(svcKey, reason, msgFmt string, args ...interface{})
SvcWarnEvent(svcKey, reason, msgFmt string, args ...interface{})
}
A SvcEventGenerator defines methods to generate Events for the Service whose namespace/name is svcKey.
Click to show internal directories.
Click to hide internal directories.